Struct plaid::webhooks::WebhookVerificationKey[][src]

pub struct WebhookVerificationKey {
    pub alg: String,
    pub crv: String,
    pub kid: String,
    pub kty: String,
    pub use: String,
    pub x: String,
    pub y: String,
    pub created_at: i64,
    pub expired_at: Option<i64>,
}

A JSON Web Key (JWK) that can be used in conjunction with JWT libraries to verify Plaid webhooks

Fields

alg: String

The alg member identifies the cryptographic algorithm family used with the key.

crv: String

The crv member identifies the cryptographic curve used with the key.

kid: String

The kid (Key ID) member can be used to match a specific key. This can be used, for instance, to choose among a set of keys within the JWK during key rollover.

kty: String

The kty (key type) parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC.

use: String

The use (public key use) parameter identifies the intended use of the public key.

x: String

The x member contains the x coordinate for the elliptic curve point.

y: String

The y member contains the y coordinate for the elliptic curve point.

created_at: i64expired_at: Option<i64>