Struct plaid::webhooks::WebhookVerificationKey [−][src]
A JSON Web Key (JWK) that can be used in conjunction with JWT libraries to verify Plaid webhooks
Fields
alg: StringThe alg member identifies the cryptographic algorithm family used with the key.
crv: StringThe crv member identifies the cryptographic curve used with the key.
kid: StringThe kid (Key ID) member can be used to match a specific key. This can be used, for instance, to choose among a set of keys within the JWK during key rollover.
kty: StringThe kty (key type) parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC.
use: StringThe use (public key use) parameter identifies the intended use of the public key.
x: StringThe x member contains the x coordinate for the elliptic curve point.
y: StringThe y member contains the y coordinate for the elliptic curve point.
created_at: i64expired_at: Option<i64>Trait Implementations
impl Clone for WebhookVerificationKey[src]
fn clone(&self) -> WebhookVerificationKey[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Debug for WebhookVerificationKey[src]
impl<'de> Deserialize<'de> for WebhookVerificationKey[src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,